<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'عربي [ar]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'جورج قندلفت (khodr1957@gmail.com) ',

	// A
	'access_interface_graphique' => 'عودة إلى الواجهة الرسومية الكاملة',
	'access_mode_texte' => 'عرض الواجهة النصية المبسّطة',
	'admin_debug' => 'اكتشاف الأخطاء',
	'admin_modifier_article' => 'تعديل هذا المقال',
	'admin_modifier_auteur' => 'تغيير هذا المؤلف',
	'admin_modifier_breve' => 'تعديل هذا الخبر',
	'admin_modifier_mot' => 'تغيير هذا المفتاح',
	'admin_modifier_rubrique' => 'تعديل هذا القسم',
	'admin_recalculer' => 'إعادة تحديث هذه الصفحة',
	'afficher_calendrier' => 'عرض الروزنامة',
	'afficher_trad' => 'عرض الترجمات',
	'alerte_maj_impossible' => '<b>تحذير!</b> ترقية قاعدة SQL إلى الإصدار @version@ متعذر. قد يكون السبب مشكلة في حقل التعديل. الرجاء الاتصال بمضيف موقعك.',
	'alerte_modif_info_concourante' => 'تحذير:هذه المعلومة عُدلت في مكان آخر. القيمة الحالية هي:',
	'analyse_xml' => 'تحليل XML',
	'annuler' => 'إلغاء',
	'antispam_champ_vide' => 'الرجاء الإبقاء على هذا الحقل فارغاً:',
	'articles_recents' => 'أحدث المقالات',
	'avis_1_erreur_saisie' => 'هناك خطأ في إدخالك، الرجاء التدقيق في المعلومات.',
	'avis_archive_incorrect' => 'ملف الأرشيف ليس ملف SPIP',
	'avis_archive_invalide' => 'ملف الأرشيف غير صالح',
	'avis_attention' => 'تحذير!',
	'avis_champ_incorrect_type_objet' => 'إسم حقل @name@ غير صالح لنوع العنصر @type@',
	'avis_colonne_inexistante' => 'العمود @col@ غير موجود',
	'avis_erreur' => 'خطأ: انظر أدناه',
	'avis_erreur_connexion' => 'خطأ اتصال',
	'avis_erreur_cookie' => 'مشكلة في الكعكة',
	'avis_erreur_fonction_contexte' => 'خطأ برمجة. لا يجب المناداة على هذه الوظيفة في هذا السياق.',
	'avis_erreur_mysql' => 'خطأ SQL ',
	'avis_erreur_sauvegarde' => 'خطأ في النسخة الاحتياطية (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'هناك مشكلة في الدخول إلى المجال الخاص',
	'avis_nb_erreurs_saisie' => 'هناك @nb@ خطأ في إدخالك، الرجاء التدقيق في المعلومات.',

	// B
	'barre_a_accent_grave' => 'إدراج حرف A كبير مع نبر الإطالة',
	'barre_aide' => 'استخدم شريط اختصارات الكتابة لإثراء تصميم صفحتك',
	'barre_e_accent_aigu' => 'إدراج حرف E كبير مع نبر حاد',
	'barre_eo' => 'إدراج E داخل O',
	'barre_eo_maj' => 'إدراج E كبير داخل O كبير',
	'barre_euro' => 'إدراج رمز €',
	'barre_gras' => '{{غامق{{',
	'barre_guillemets' => 'إحاطة «بعلامتي اقتباس مزدوجة»',
	'barre_guillemets_simples' => 'وضع بين "علامتي اقتباس مزدوجة من المستوى الثاني"',
	'barre_intertitre' => 'تحويل إلى {{{عنوان فقرة}}}',
	'barre_italic' => '{مائل{',
	'barre_lien' => 'تحويل إلى [وصلة هايبرتكست->http://...]',
	'barre_lien_input' => 'الرجاء إدخال عنوان الوصلة (يمكنك إدخال عنوان نسيج على شكل http://www.mysite.com أو إدخال رقم مقال من الموقع الحالي فقط).',
	'barre_note' => 'تحويل إلى [[حاشية]]',
	'barre_paragraphe' => 'إنشاء فقرة',
	'barre_quote' => '<quote>اقتباس رسالة</quote>',
	'bouton_changer' => 'تغيير',
	'bouton_chercher' => 'بحث',
	'bouton_choisir' => 'تحديد',
	'bouton_deplacer' => 'نقل',
	'bouton_download' => 'تحميل',
	'bouton_enregistrer' => 'إدخال',
	'bouton_radio_desactiver_messagerie_interne' => 'إيقاف المراسلة الداخلية',
	'bouton_radio_envoi_annonces' => 'إرسال إعلانات التحرير',
	'bouton_radio_non_envoi_annonces' => 'عدم إرسال الإعلانات',
	'bouton_radio_non_envoi_liste_nouveautes' => 'عدم إرسال قائمة بآخر الأخبار',
	'bouton_recharger_page' => 'إعادة تحميل الصفحة',
	'bouton_telecharger' => 'تحميل',
	'bouton_upload' => 'تنزيل',
	'bouton_valider' => 'إدخال',

	// C
	'cal_apresmidi' => 'بعد الظهر',
	'cal_jour_entier' => 'يوم كامل',
	'cal_matin' => 'الصباح',
	'cal_par_jour' => 'روزنامة يومية',
	'cal_par_mois' => 'روزنامة شهرية',
	'cal_par_semaine' => 'روزنامة أسبوعية',
	'choix_couleur_interface' => 'اللون',
	'choix_interface' => 'اختيار الواجهة',
	'colonne' => 'عمود',
	'confirm_changer_statut' => 'تحذير، لقد طلبت تغيير حالة هذا العنصر. هل تريد المتابعة؟',
	'correcte' => 'صحيح',

	// D
	'date_aujourdhui' => 'اليوم',
	'date_avant_jc' => 'قبل الميلاد',
	'date_dans' => 'بعد @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'غداً',
	'date_fmt_heures_minutes' => '@h@  و@m@  دقيقة',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ الساعة @heure@',
	'date_fmt_jour_heure_debut_fin' => 'في @jour@ من @heure_debut@ الى @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => 'في @dtstart@@jour@ من @heure_debut@@dtabbr@ الى @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'في @nomjour@ @date@',
	'date_fmt_periode' => 'من @date_debut@ الى @date_fin@',
	'date_fmt_periode_abbr' => 'من @dtart@@date_debut@@dtabbr@ الى @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'من',
	'date_fmt_periode_to' => 'الى',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'ساعة',
	'date_hier' => 'البارحة',
	'date_il_y_a' => 'منذ @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'الأحد',
	'date_jour_1_abbr' => 'أحد',
	'date_jour_1_initiale' => 'أحد',
	'date_jour_2' => 'الاثنين',
	'date_jour_2_abbr' => 'اثنين',
	'date_jour_2_initiale' => 'اثنين',
	'date_jour_3' => 'الثلاثاء',
	'date_jour_3_abbr' => 'ثلاثاء',
	'date_jour_3_initiale' => 'ثلاثاء',
	'date_jour_4' => 'الأربعاء',
	'date_jour_4_abbr' => 'أربعاء',
	'date_jour_4_initiale' => 'أربعاء',
	'date_jour_5' => 'الخميس',
	'date_jour_5_abbr' => 'خميس',
	'date_jour_5_initiale' => 'خميس',
	'date_jour_6' => 'الجمعة',
	'date_jour_6_abbr' => 'جمعة',
	'date_jour_6_initiale' => 'جمعة',
	'date_jour_7' => 'السبت',
	'date_jour_7_abbr' => 'سبت',
	'date_jour_7_initiale' => 'سبت',
	'date_jours' => 'يوم',
	'date_minutes' => 'دقيقة',
	'date_mois' => 'شهر',
	'date_mois_1' => 'كانون الثاني (يناير)',
	'date_mois_10' => 'تشرين الأول (أكتوبر)',
	'date_mois_10_abbr' => 'ت١',
	'date_mois_11' => 'تشرين الثاني (نوفمبر)',
	'date_mois_11_abbr' => 'ت٢',
	'date_mois_12' => 'كانون الأول (ديسمبر)',
	'date_mois_12_abbr' => 'ك١',
	'date_mois_1_abbr' => 'ك٢',
	'date_mois_2' => 'شباط (فبراير)',
	'date_mois_2_abbr' => 'شباط',
	'date_mois_3' => 'آذار (مارس)',
	'date_mois_3_abbr' => 'آذار',
	'date_mois_4' => 'نيسان (أبريل)',
	'date_mois_4_abbr' => 'نيسان',
	'date_mois_5' => 'أيار (مايو)',
	'date_mois_5_abbr' => 'أيار',
	'date_mois_6' => 'حزيران (يونيو)',
	'date_mois_6_abbr' => 'جزيران',
	'date_mois_7' => 'تموز (يوليو)',
	'date_mois_7_abbr' => 'تموز',
	'date_mois_8' => 'آب (أغسطس)',
	'date_mois_8_abbr' => 'آب',
	'date_mois_9' => 'أيلول (سبتمبر)',
	'date_mois_9_abbr' => 'أيلول',
	'date_saison_1' => 'الشتاء',
	'date_saison_2' => 'الربيع',
	'date_saison_3' => 'الصيف',
	'date_saison_4' => 'الخريف',
	'date_secondes' => 'ثانية',
	'date_semaines' => 'أسبوع',
	'date_un_mois' => 'شهر',
	'date_une_heure' => 'ساعة',
	'date_une_minute' => 'دقيقة',
	'date_une_seconde' => 'ثانية',
	'date_une_semaine' => 'أسبوع',
	'dirs_commencer' => 'للبدء فعلاً بعملية التثبيت',
	'dirs_preliminaire' => 'تمهيد: <b>إعداد امتيازات الدخول</b>',
	'dirs_probleme_droits' => 'مشكلة في امتيازات الدخول',
	'dirs_repertoires_absents' => '<p><b>لم يتم العثور على الأدلة التالية: </b></p><ul>@bad_dirs@</ul>
<p>قد يكون السبب خطأ في اعتماد الحروف الكبيرة أو الصغيرة في أسمائها. الرجاء التأكد من أن الحروف الكبيرة والصغيرة في أسماء هذه الأدلة تناسب ما هو معروض أعلاه؛ إذا لم يكن الأمر كذلك، الرجاء إعادة تسمية الأدلة بواسطة برنامج FTP لتصحيح الخطأ.
<p>بعد تنفيذ هذه العملية يمكنك </p>',
	'dirs_repertoires_suivants' => '<p><b>الأدلة التالية ممنوعة على الكتابة: </b></p
<ul>@bad_dirs@</ul>
<p>لحل هذه المشكلة، استخدم برنامج FTP لإعداد امتيازات الدخول لكل من هذه الأدلة. ويوضح دليل الاستخدام هذه العملية بالتفصيل.
<p>بعد إتمام هذه العملية يمكنك</p>',
	'double_occurrence' => 'ظهور مكرر لعلامة @balise@',

	// E
	'en_cours' => 'جاري',
	'envoi_via_le_site' => 'إرسال عبر الموقع',
	'erreur' => 'خطأ',
	'erreur_balise_non_fermee' => 'آخر علامة غير مغلقة:',
	'erreur_technique_ajaxform' => 'عفواً. حدث خطأ غير متوقع خلال إرسال الاستمارة. الرجاء المحاولة من جديد.',
	'erreur_technique_enregistrement_champs' => 'خطأ تقني منع التسجيل السليم للحقل @champs@. ',
	'erreur_technique_enregistrement_impossible' => 'خطأ تقني منع التسجيل.',
	'erreur_texte' => 'خطأ (أخطاء)',
	'etape' => 'خطوة',

	// F
	'fichier_introuvable' => 'لا يمكن العثور على الملف @fichier@',
	'form_auteur_confirmation' => 'تأكيد عنوان البريد الالكتروني',
	'form_auteur_email_modifie' => 'تغير عنوان بريدك.',
	'form_auteur_envoi_mail_confirmation' => 'لفد تم ارسال بريد تأكيد الى @email@. عليك زيارة عنوان الموقع الموجود في الرسالة للتصديق على عنوان بريدك.',
	'form_auteur_mail_confirmation' => 'أهلاً وسهلاً

لقد طلبت تغيير عنوان بريدك.
للتصديق على العنوان الجديد، يكفي الاتصال
بالعنوان أدناه (والا سيتم تجاهل
طلبك):

    @url@
',
	'form_deja_inscrit' => 'سبق لك التسجيل.',
	'form_email_non_valide' => 'عنوانك البريدي غير صالح.',
	'form_forum_access_refuse' => 'لم تعد تملك امتياز الدحول إلى هذا الموقع.',
	'form_forum_bonjour' => 'مرحباً @nom@،',
	'form_forum_confirmer_email' => 'لتأكيد عنوان بريدك، إذهب الى:@url_confirm@',
	'form_forum_email_deja_enregistre' => 'سبق تسجيل هذا العنوان البريدي، يمكنك إذاً استخدام كلمة سرك الاعتيادية.',
	'form_forum_identifiant_mail' => 'لقد تم إرسال معرّفك الجديد بالبريد الالكتروني.',
	'form_forum_identifiants' => 'بيانات الاتصال الشخصية',
	'form_forum_indiquer_nom_email' => 'قم بإدخال اسمك وعنوانك البريدي هنا. ستحصل على بيانات اتصالك قريباً في البريد الإلكتروني.',
	'form_forum_login' => 'المعرّف:',
	'form_forum_message_auto' => '(هذه رسالة آلية)',
	'form_forum_pass' => 'كلمة السر:',
	'form_forum_probleme_mail' => 'مشكلة بريد إلكتروني: لا يمكن إرسال بيانات الدخول.',
	'form_forum_voici1' => 'هذه هي بياناتك للاشتراك في نشاط
الموقع  "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'هذه هي بياناتك لاقتراح مقالات
للموقع  "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'الرجاء إدخال عنوانك الإلكتروني.',
	'form_indiquer_nom' => 'الرجاء إدخال اسمك.',
	'form_indiquer_nom_site' => 'الرجاء إدخال إسم موقعك.',
	'form_pet_deja_enregistre' => 'سبق تسجيل هذا الموقع',
	'form_pet_signature_pasprise' => 'تم تجاهل توقيعك.',
	'form_prop_confirmer_envoi' => 'تأكيد الإرسال',
	'form_prop_description' => 'وصف/تعليق',
	'form_prop_enregistre' => 'تم تسجيل اقتراحك، سوف يظهر بعد تصديقه من قبل مسئولي هذا الموقع.',
	'form_prop_envoyer' => 'ابعث برسالة',
	'form_prop_indiquer_email' => 'الرجاء إدخال عنوان بريد إلكتروني صالح',
	'form_prop_indiquer_nom_site' => 'الرجاء إدخال اسم الموقع.',
	'form_prop_indiquer_sujet' => 'الرجاء إدخال موضوع',
	'form_prop_message_envoye' => 'تم بعث الرسالة',
	'form_prop_non_enregistre' => 'لم يتم تسجيل اقتراحك.',
	'form_prop_sujet' => 'الموضوع',
	'form_prop_url_site' => 'عنوان الموقع',
	'forum_non_inscrit' => 'إما انك غير مسجل أو هناك خطأ في العنوان أو كلمة السر.',
	'forum_par_auteur' => 'من @auteur@',
	'forum_titre_erreur' => 'خطأ...',

	// I
	'ical_texte_rss_articles' => 'يوجد ملف «الترخيص الخلفي» لمقالات هذا الموقع على العنوان: ',
	'ical_texte_rss_articles2' => 'يمكنك أيضاً الحصول على ملفات «الترخيص الخلفي» لمقالات كل قسم في الموقع:',
	'ical_texte_rss_breves' => 'يوجد كذلك ملف يحتوي على أخبار الموقع. وبإدخال رقم قسم ما، تحصل على أخبار هذا القسم فقط.',
	'icone_a_suivre' => 'للمتابعة',
	'icone_admin_site' => 'إدارة الموقع',
	'icone_agenda' => 'المفكرة',
	'icone_aide_ligne' => 'التعليمات الفورية',
	'icone_articles' => 'المقالات',
	'icone_auteurs' => 'المؤلفون',
	'icone_brouteur' => 'تصفح سريع',
	'icone_configuration_site' => 'إعداد',
	'icone_configurer_site' => 'إعداد موقعك',
	'icone_creer_nouvel_auteur' => 'إضافة مؤلف جديد',
	'icone_creer_rubrique' => 'إنشاء قسم',
	'icone_creer_sous_rubrique' => 'إنشاء قسم فرعي',
	'icone_deconnecter' => 'خروج',
	'icone_discussions' => 'نقاشات',
	'icone_doc_rubrique' => 'مستندات الأقسام',
	'icone_ecrire_article' => 'كتابة مقال جديد',
	'icone_edition_site' => 'تحرير الموقع',
	'icone_gestion_langues' => 'إدارة اللغات',
	'icone_informations_personnelles' => 'المعلومات الشخصية',
	'icone_interface_complet' => 'واجهة كاملة',
	'icone_interface_simple' => 'واجهة مبسّطة',
	'icone_maintenance_site' => 'صيانة الموقع',
	'icone_messagerie_personnelle' => 'المراسلة الشخصية',
	'icone_repartition_debut' => 'إظهار التوزيع منذ البداية',
	'icone_rubriques' => 'الأقسام',
	'icone_sauver_site' => 'نسخة احتياطية للموقع',
	'icone_site_entier' => 'الموقع بالكامل',
	'icone_sites_references' => 'المواقع المبوبة',
	'icone_statistiques' => 'إحصاءات الموقع',
	'icone_suivi_activite' => 'متابعة نشاط الموقع',
	'icone_suivi_actualite' => 'تطور الموقع',
	'icone_suivi_pettions' => 'متابعة/إدارة العرائض',
	'icone_suivi_revisions' => 'تعديل المقالات',
	'icone_supprimer_document' => 'حذف هذا المستند',
	'icone_supprimer_image' => 'حذف هذه الصورة',
	'icone_tous_articles' => 'كل مقالاتك',
	'icone_tous_auteur' => 'جميع المؤلفين',
	'icone_tous_visiteur' => 'جميع الزوار',
	'icone_visiter_site' => 'تصفح الموقع العمومي',
	'icone_voir_en_ligne' => 'عرض مباشر',
	'img_indisponible' => 'صورة غير متوفرة',
	'impossible' => 'مستحيل',
	'info_a_suivre' => 'للمتابعة»',
	'info_acces_interdit' => 'الدخول محظور',
	'info_acces_refuse' => 'دخول محظور',
	'info_action' => 'عملية: @action@',
	'info_administrer_rubriques' => 'يمكنك إدارة هذا القسم وأقسامه الفرعية',
	'info_adresse_non_indiquee' => 'لم تدخل أي عنوان لاختباره!',
	'info_aide' => 'تعليمات :',
	'info_ajouter_mot' => 'إضافة هذا المفتاح',
	'info_annonce' => 'إعلان',
	'info_annonces_generales' => 'إعلانات عامة:',
	'info_article_propose' => 'مقال مقترح',
	'info_article_publie' => 'مقال منشور',
	'info_article_redaction' => 'مقال قيد التحرير',
	'info_article_refuse' => 'مقال مرفوض',
	'info_article_supprime' => 'مقال محذوف',
	'info_articles' => 'المقالات',
	'info_articles_a_valider' => 'مقالات معروضة للتصديق',
	'info_articles_nb' => '@nb@ مقال',
	'info_articles_proposes' => 'المقالات المعروضة',
	'info_articles_un' => 'مقال واحد',
	'info_auteurs_nombre' => 'مؤلف (مؤلفون):',
	'info_authentification_ftp' => 'التحقق ( عبر بروتوكول FTP ).',
	'info_breves_2' => 'خبر',
	'info_breves_nb' => '@nb@ خبر',
	'info_breves_un' => 'خبر واحد',
	'info_connexion_refusee' => 'رفض الاتصال',
	'info_contact_developpeur' => 'الرجاء الاتصال بمطوّر.',
	'info_contenance' => 'هذا الموقع يحتوي على:',
	'info_contribution' => 'مشاركة منتديات',
	'info_copyright' => '@spip@ برنامج حر موزع @lien_gpl@.',
	'info_copyright_doc' => 'لمزيد من المعلومات راجع الموقع<a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'بموجب الترخيص العام GPL',
	'info_cours_edition' => 'قيد التحرير',
	'info_creer_repertoire' => 'الرجاء إنشاء ملف أو دليل باسم',
	'info_creer_repertoire_2' => 'داخل الدليل الفرعي <b>@repertoire@</b>، ثم:',
	'info_creer_vignette' => 'إنشاء آلي للمصغر',
	'info_creerdansrubrique_non_autorise' => 'لا تملك الحقوق الكافية لإنشاء اي محتوى في هذا القسم',
	'info_deplier' => 'بسط',
	'info_descriptif_nombre' => 'الوصف:',
	'info_description' => 'الوصف:',
	'info_description_2' => 'الوصف:',
	'info_dimension' => 'الحجم:',
	'info_documents_nb' => '@nb@ مستند',
	'info_documents_un' => 'مستند واحد',
	'info_ecire_message_prive' => 'تحرير رسالة خاصة',
	'info_email_invalide' => 'عنوان بريد غير صالح.',
	'info_en_cours_validation' => 'مقالاتك قيد التحرير',
	'info_en_ligne' => 'متصل حالياً:',
	'info_envoyer_message_prive' => 'ابعث برسالة خاصة لهذا المؤلف',
	'info_erreur_requete' => 'خطأ في الاستفسار:',
	'info_erreur_squelette2' => 'لا توجد صفحة نموذجية <b>@fichier@</b> متاحة...',
	'info_erreur_systeme' => 'خطأ في النظام (خطأ رقم @errsys@)',
	'info_erreur_systeme2' => 'قد يكون القرص الصلب ممتلئاً أو قد تكون قاعدة البيانات معطلة.<br />
<span style="color:red;">حاول <a href=\'@script@\'>إصلاح القاعدة</a>، أو الاتصال بمضيف موقعك.</font> ',
	'info_fini' => 'انتهى!',
	'info_format_image' => 'تنسيق ملفات الصور الذي يمكن استخدامه لإنشاء المصغرات: @gd_formats@ .',
	'info_format_non_defini' => 'تنسيق غير معروف',
	'info_grand_ecran' => 'شاشة كبيرة',
	'info_image_aide' => 'تعليمات',
	'info_image_process_titre' => 'طريقة إنشاء المصغرات',
	'info_impossible_lire_page' => '<b>خطأ!</b> لا يمكن قراءة الصفحة <tt><html>@test_proxy@</html></tt> عبر الجهاز الوكيل',
	'info_installation_systeme_publication' => 'تثبيت نظام النشر...',
	'info_installer_documents' => 'يمكنك تثبيت كل المستندات الموجودة في المجلد @upload@ آلياً.',
	'info_installer_ftp' => 'بصفتك مديراً، يمكنك تثبيت (بواسطة بروتوكول FTP) ملفات في المجلد@upload@  من أجل تحديدهم في ما بعد مباشرة من هنا.',
	'info_installer_images' => 'يمكنك تثبيت صور بتنسيقات JPEG  وGIF  وPNG.',
	'info_installer_images_dossier' => 'تثبيت صور في المجلد @upload@  للتمكن من تحديدها هنا.',
	'info_interface_complete' => 'واجهة كاملة',
	'info_interface_simple' => 'واجهة مبسّطة',
	'info_joindre_document_article' => 'يمكنك إرفاق مقالك بمستندات من الأنواع',
	'info_joindre_document_rubrique' => 'يمكنك إضافة مستندات من الأنواع التالية إلى هذا القسم',
	'info_joindre_documents_article' => 'يمكنك إرفاق مستندات من الأنواع التالية بمقالك :',
	'info_l_article' => 'المقال',
	'info_la_breve' => 'الخبر',
	'info_la_rubrique' => 'القسم',
	'info_langue_principale' => 'اللغة الأساسية للموقع',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@  نقطة',
	'info_les_auteurs_1' => 'من @les_auteurs@',
	'info_logo_format_interdit' => 'الرموز بتنسيق @formats@ هي الوحيدة المسموح بها.',
	'info_logo_max_poids' => 'يجب ألا يتعدى حجم الرموز @maxi@ (يبلغ حجم الملف الحالي @actuel@). ',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'رسالة',
	'info_message_supprime' => 'تم حذف المشاركة',
	'info_messages_nb' => '@nb@ رسالة',
	'info_messages_un' => 'رسالة واحدة',
	'info_mise_en_ligne' => 'تاريخ النشر:',
	'info_modification_parametres_securite' => 'تعديل إعدادات الأمان',
	'info_mois_courant' => 'في بحر الشهر:',
	'info_mot_cle_ajoute' => 'تمت إضافة المفتاح التالي إلى',
	'info_multi_herit' => 'اللغة الافتراضية',
	'info_multi_langues_soulignees' => '<u>اللغات التي تحتها خط</u> تتمتع بترجمة كاملة او جزئية لكل نصوص الواجهة. فإذا حددت هذه اللغات، سيتم ترجمة العديد من عناصر الموقع العمومي (التواريخ والاستمارات) آلياً. أما بالنسبة للغات التي ليس تحتها خط، فستظهر هذه العناصر في لغة الموقع الأساسية.',
	'info_multilinguisme' => 'تعدد اللغات',
	'info_nom_non_utilisateurs_connectes' => 'اسمك لا يظهر في قائمة المستخدمين المتصلين.',
	'info_nom_utilisateurs_connectes' => 'اسمك يظهر في قائمة المستخدمين المتصلين.',
	'info_nombre_en_ligne' => 'متصل حالياً:',
	'info_non_resultat' => 'لا توجد نتائج لـ "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'أنت لا تستخدم المراسلة الداخلية في هذا الموقع.',
	'info_nouveau_message' => 'وصلت رسالة جديدة',
	'info_nouveaux_messages' => 'وصلت @total_messages@  رسالة جديدة',
	'info_numero_abbreviation' => 'رقم',
	'info_obligatoire' => 'هذه المعلومة إجبارية',
	'info_pense_bete' => 'مذكرة',
	'info_petit_ecran' => 'شاشة صغيرة',
	'info_petition_close' => 'عريضة مقفلة',
	'info_pixels' => 'نقطة',
	'info_plusieurs_mots_trouves' => 'تم العثور على عدة مفاتيح لـ "@cherche_mot@" :',
	'info_portfolio_automatique' => 'محفظة آلية:',
	'info_premier_resultat' => '[النتائج الـ@debut_limit@  الأولى من أصل @total@]',
	'info_premier_resultat_sur' => '[النتائج الـ@debut_limit@  الأولى من أصل @total@]',
	'info_propose_1' => '[@nom_site_spip@] يقترح: @titre@',
	'info_propose_2' => 'مقال معروض
----------',
	'info_propose_3' => 'المقال "@titre@" معروض للنشر.',
	'info_propose_4' => 'أنت مدعو لمراجعته وإبداء رأيك',
	'info_propose_5' => 'في المنتدى المرتبط به. إنه موجود على العنوان:',
	'info_publie_01' => 'تم التصديق على المقال "@titre@"  من قبل @connect_nom@ .',
	'info_publie_1' => '[@nom_site_spip@] ينشر: @titre@',
	'info_publie_2' => 'مقال منشور
----------',
	'info_rechercher' => 'بحث',
	'info_rechercher_02' => 'بحث:',
	'info_remplacer_vignette' => 'استبدال المصغر الافتراضي بشعار شخصي:',
	'info_rubriques_nb' => '@nb@ قسم',
	'info_rubriques_un' => 'قسم واحد',
	'info_sans_titre_2' => 'بدون عنوان',
	'info_selectionner_fichier' => 'يمكنك تحديد ملف من المجلد @upload@:',
	'info_selectionner_fichier_2' => 'تحديد ملف:',
	'info_sites_nb' => '@nb@ موقع',
	'info_sites_un' => 'موقع واحد',
	'info_supprimer_vignette' => 'حذف المصغر',
	'info_symbole_bleu' => 'الرمز <b>أزرق</b> يرمز إلى <b>مذكرة</b>: أي رسالة لاستخدامك الشخصي.',
	'info_symbole_jaune' => 'الرمز <b>أصفر</b> يرمز إلى <b>إعلان لجميع المحررين</b>: يمكن لجميع المدراء تحريره وهو ظاهر لجميع المحررين.',
	'info_symbole_vert' => 'الرمز <b>أخضر</b>  يرمز إلى <b>الرسائل المتبادلة بين مستخدمي</b> الموقع.',
	'info_telecharger_nouveau_logo' => 'تحميل شعار جديد:',
	'info_telecharger_ordinateur' => 'تحميل من جهازك:',
	'info_tous_resultats_enregistres' => '[تم تسجيل كل النتائج]',
	'info_tout_afficher' => 'إظهار الكل',
	'info_travaux_texte' => 'هذا الموقع قيد الإعداد. برجاء العودة في وقت لاحق...',
	'info_travaux_titre' => 'موقع قيد التصميم',
	'info_trop_resultat' => 'تم العثور على عدد كبير جداً من النتائج لـ "@cherche_mot@" ، الرجاء زيادة دقة البحث.',
	'info_utilisation_messagerie_interne' => 'أنت تستخدم المراسلة الداخلية في هذا الموقع.',
	'info_valider_lien' => 'التصديق على هذه الوصلة',
	'info_verifier_image' => '، الرجاء التأكد من أنه تم نقل الصور بشكل سليم.',
	'info_vignette_defaut' => 'المصغر الافتراضي',
	'info_vignette_personnalisee' => 'مصغر شخصي',
	'info_visite' => 'زيارة:',
	'info_vos_rendez_vous' => 'مواعيدك القادمة',
	'infos_vos_pense_bete' => 'مذكراتك',

	// L
	'label_ajout_id_rapide' => 'إضافة سريعة',
	'label_poids_fichier' => 'الحجم',
	'lien_afficher_icones_seuls' => 'عرض الرموز فقط',
	'lien_afficher_texte_icones' => 'عرض الرموز والعناوين',
	'lien_afficher_texte_seul' => 'عرض العناوين فقط',
	'lien_liberer' => 'فك الحجز',
	'lien_liberer_tous' => 'فك حجز الكل',
	'lien_nouvea_pense_bete' => 'مذكرة جديدة',
	'lien_nouveau_message' => 'رسالة جديدة',
	'lien_nouvelle_annonce' => 'إعلان جديد',
	'lien_petitions' => 'عريضة',
	'lien_popularite' => 'شعبية: @popularite@%',
	'lien_racine_site' => 'أصل الموقع',
	'lien_reessayer' => 'إعادة المحاولة',
	'lien_repondre_message' => 'الرد على هذه المشاركة',
	'lien_supprimer' => 'حذف',
	'lien_tout_afficher' => 'إظهار الكل',
	'lien_visite_site' => 'زيارة هذا الموقع',
	'lien_visites' => '@visites@ زيارة',
	'lien_voir_auteur' => 'مراجعة هذا المؤلف',
	'ligne' => 'سطر',
	'login' => 'الدخول',
	'login_acces_prive' => 'الدخول إلى المجال الخاص',
	'login_autre_identifiant' => 'الاتصال بمعرّف آخر',
	'login_cookie_accepte' => 'الرجاء تهيئ برنامج التصفح ليتقبلها (من هذا الموقع على الأقل)',
	'login_cookie_oblige' => 'للتعريف عن نفسك بشكل آمن في هذا الموقع، يجب قبول الكعكات (cookies).',
	'login_deconnexion_ok' => 'تم قطع الاتصال.',
	'login_erreur_pass' => 'خطأ في كلمة السر.',
	'login_espace_prive' => 'المجال الخاص',
	'login_identifiant_inconnu' => 'المعرّف «@login@» غير معروف.',
	'login_login' => 'المعرّف:',
	'login_login2' => 'المعرّف او عنوان البريد الالكتروني:',
	'login_login_pass_incorrect' => '(خطأ في المعرّف أو كلمة السر).',
	'login_motpasseoublie' => 'هل نسيت كلمة السر؟',
	'login_non_securise' => 'لطفا، هذه الاستمارة غير آمنة.
   إذا كنت ترغب أن تكون كلمة سرك
   آمنة على الشبكة، يجب تفعيل جافاسكريبت 
   في برنامج التصفح',
	'login_nouvelle_tentative' => 'محاولة جديدة',
	'login_par_ici' => 'أنت مسجّل... توجه من هنا...',
	'login_pass2' => 'كلمة السر:',
	'login_preferez_refuser' => '<b>إذا كنت تفضل عدم قبول الكعكات</b>، يمكنك استخدام طريقة دخول أخرى (أقل أماناً):',
	'login_recharger' => 'وإعادة تحميل الصفحة',
	'login_rester_identifie' => 'ابقى متصلاً بضعة أيام',
	'login_retour_public' => 'عودة إلى الموقع العام',
	'login_retour_site' => 'عودة إلى الموقع العام',
	'login_retoursitepublic' => 'عودة إلى الموقع العام',
	'login_sans_cookie' => 'تعريف بدون الكعكة',
	'login_securise' => 'تعريف مؤمّن',
	'login_sinscrire' => 'تسجيل',
	'login_test_navigateur' => 'تجربة المتصفح/إعادة الاتصال',
	'login_verifiez_navigateur' => '(على أي حال، تأكد من أن المتصفح لم يقم بحفظ كلمة سرك...)',

	// M
	'masquer_colonne' => 'حجب هذا العمود',
	'masquer_trad' => 'حجب الترجمات',
	'module_fichiers_langues' => 'ملفات اللغة',

	// N
	'navigateur_pas_redirige' => 'إذا لم تتم إعادة توجيه متصفحك، انقر هنا للمتابعة.',
	'numero' => 'رقم',

	// O
	'occurence' => 'ظهور',
	'onglet_affacer_base' => 'حذف قاعدة البيانات',
	'onglet_auteur' => 'المؤلف',
	'onglet_contenu_site' => 'محتوى الموقع',
	'onglet_evolution_visite_mod' => 'تطور',
	'onglet_fonctions_avances' => 'الوظائف المتطورة',
	'onglet_informations_personnelles' => 'المعلومات الشخصية',
	'onglet_interactivite' => 'التفاعلية',
	'onglet_messagerie' => 'المراسلة',
	'onglet_repartition_rubrique' => 'التوزيع حسب الأقسام',
	'onglet_save_restaur_base' => 'نسخ احتياطي / استرجاع القاعدة',
	'onglet_vider_cache' => 'تفريغ الذاكرة المخبأة',

	// P
	'pass_choix_pass' => 'الرجاء اختيار كلمة السر الجديدة:',
	'pass_erreur' => 'خطأ',
	'pass_erreur_acces_refuse' => '<b>خطأ:< b> لم تعد تملك حق الدخول إلى هذا الموقع.',
	'pass_erreur_code_inconnu' => '<b>خطأ:< b> هذا المعرّف لا يتناسب مع أي من الزوار الذين يتمتعون بحق الدخول إلى هذا الموقع.',
	'pass_erreur_non_enregistre' => '<b>خطأ:< b>  العنوان <tt>@email_oubli@</tt> ليس مسجلاً في هذا الموقع.',
	'pass_erreur_non_valide' => '<b>خطأ:< b>  العنوان <tt>@email_oubli@</tt> ليس صالحاً.',
	'pass_erreur_probleme_technique' => '<b>خطأ:< b>  لم يتم بعث هذه الرسالة بسبب مشكلة تقنية.',
	'pass_espace_prive_bla' => 'المجال الخاص لهذا الموقع مفتوح
للزوار بعد تسجيلهم. بعد تسجيلك
يمكنك مراجعة المقالات قيد التحرير
واقتراح مقالات والمشاركة في كل المنتديات.',
	'pass_forum_bla' => 'طلبت المشاركة في منتدى
محصور بالزوار المسجلين.',
	'pass_indiquez_cidessous' => 'قم بإدخال العنوان الإلكتروني الذي 
تسجلت بواستطه سابقاً.
ستحصل على رسالة تفسر لك كيفية
استعادة دخولك.',
	'pass_mail_passcookie' => '(هذه رسالة آلية)
لاستعادة دخولك إلى الموقع
@nom_site_spip@  (@adresse_site@)

الرجاء الذهاب إلى العنوان التالي:

    @sendcookie@

يمكنك عندها إدخال كلمة سر جديدة
وإعادة الاتصال بالموقع.

',
	'pass_mot_oublie' => 'نسيان كلمة السر',
	'pass_nouveau_enregistre' => 'تم تسجيل كلمة سرك الجديدة.',
	'pass_nouveau_pass' => 'كلمة السر الجديدة',
	'pass_ok' => 'موافق',
	'pass_oubli_mot' => 'نسيان كلمة السر',
	'pass_procedure_changer' => 'من أجل تغيير كلمة السر، قم بأدخال عنوان البريد الالكتروني المرتبط بحسابك.',
	'pass_quitter_fenetre' => 'إقفال هذه النافذة',
	'pass_rappel_login' => 'تذكير: معرّفك هو «@login@».',
	'pass_recevoir_mail' => 'ستحصل على رسالة تفسر لك كيف تستعيد دخولك إلى الموقع.',
	'pass_retour_public' => 'عودة إلى الموقع العام',
	'pass_rien_a_faire_ici' => 'لا شغل لك هنا.',
	'pass_vousinscrire' => 'تسجيلك في الموقع',
	'precedent' => 'السابق',
	'previsualisation' => 'عرض مسبق',
	'previsualiser' => 'عرض مسبق',

	// R
	'retour' => 'عودة',

	// S
	'spip_conforme_dtd' => 'يعتبر SPIP أن هذا المستند مطابق لتحديد DOCTYPE:',
	'squelette' => 'صفحة نموذجية',
	'squelette_inclus_ligne' => 'صفحة نموذجية مدمجة، سطر',
	'squelette_ligne' => 'صفحة نموذجية، سطر',
	'stats_visites_et_popularite' => '@visites@ زيارة؛ شعبية: @popularite@',
	'suivant' => 'التالي',

	// T
	'taille_go' => '@taille@ غيغابايت',
	'taille_ko' => '@taille@ كيلوبايت',
	'taille_mo' => '@taille@ ميغابايت',
	'taille_octets' => '@taille@ بايت',
	'texte_actualite_site_1' => 'عندما تتأقلم مع واجهة النظام انقر على «',
	'texte_actualite_site_2' => 'الواجهة الكاملة',
	'texte_actualite_site_3' => '»  لإتاحة المزيد من الوظائف.',
	'texte_creation_automatique_vignette' => 'لقد تم تفعيل الإنشاء الآلي لمصغرات المعاينة. إذا استخدمت هذه الاستمارة لإدخال صور بتنسيق (أو تنسيقات) @gd_formats@، سيتم تزويدها بمصغر لا يزيد حجمه عن @taille_preview@  نقطة. ',
	'texte_documents_associes' => 'المستندات التالية ترافق المقال،
    لكنها لم تُدرج
    مباشرة. بالاعتماد على تصميم الموقع العمومي،
    قد تظهر على شكل مستندات مرفقة.',
	'texte_erreur_mise_niveau_base' => 'خطأ في قاعدة البيانات خلال الترقية.
     تعذر تمرير الصورة <b>@fichier@</b>  (المقال @id_article@). 
     سجل هذا المرجع وحاول إعادة عملية
     الترقية، وأخيراً تأكد من أن الصور لا تزال تظهر
     في المقالات.',
	'texte_erreur_visiteur' => 'حاولت الدخول إلى المجال الخاص بمعرّف لا يسمح بذلك.',
	'texte_inc_auth_1' => 'عرّفت عن نفسك
بالمعرّف <b>@auth_login@</b>، لكنه غير (لم يعد) موجود في قاعدة البيانات.
  حاول  ',
	'texte_inc_auth_2' => 'إعادة الاتصال',
	'texte_inc_auth_3' => '، بعد إنهاء المتصفح ثم
إعادة تشغيله إذا اقتضت الحاجة.',
	'texte_inc_config' => 'التغييرات الداخلة على هذه الصفحة تؤثر بشكل ملحوظ على
تشغيل الموقع. يستحسن عدم إدخال تغييرات قبل
التأقلم مع نظام SPIP  للنشر. <br /><br /><b>بشكل
عام، ننصحك
بحصر التعامل مع هذه الصفحات بالمسؤول الأساسي عن تصميم الموقع.</b>',
	'texte_inc_meta_1' => 'واجه النظام خطأً خلال كتابة الملف <code>@fichier@</code>. بصفتك أحد مدراء الموقع، الرجاء',
	'texte_inc_meta_2' => 'التأكد من حقوق الكتابة',
	'texte_inc_meta_3' => 'الخاصة بالدليل <code>@repertoire@</code>. ',
	'texte_statut_en_cours_redaction' => 'قيد التحرير',
	'texte_statut_poubelle' => 'إلى المهملات',
	'texte_statut_propose_evaluation' => 'معروض للتقييم',
	'texte_statut_publie' => 'منشور',
	'texte_statut_refuse' => 'مرفوض',
	'titre_ajouter_mot_cle' => 'إضافة مفتاح:',
	'titre_cadre_raccourcis' => 'اختصارات:',
	'titre_changer_couleur_interface' => 'تغيير لون الواجهة',
	'titre_image_admin_article' => 'أنت مخول إدارة هذا المقال',
	'titre_image_administrateur' => 'مدير',
	'titre_image_aide' => 'تعليمات حول هذا العنصر',
	'titre_image_auteur_supprime' => 'مؤلف محذوف',
	'titre_image_redacteur' => 'محرر دون إذن دخول',
	'titre_image_redacteur_02' => 'محرر',
	'titre_image_selecteur' => 'عرض القائمة',
	'titre_image_visiteur' => 'زائر',
	'titre_joindre_document' => 'إرفاق مستند',
	'titre_mots_cles' => 'المفاتيح',
	'titre_probleme_technique' => 'تحذير: مشكلة تقنية (خادم SQL) تمنع الدخول إلى هذا الجزء من الموقع. شكراً على تفهمكم.',
	'titre_publier_document' => 'نشر مستند في هذا القسم',
	'titre_signatures_attente' => 'تواقيع بانتظار التصديق',
	'titre_signatures_confirmees' => 'توقيعات مصدّقة',
	'titre_statistiques' => 'إحصاءات الموقع',
	'titre_titre_document' => 'اسم المستند: ',
	'todo' => 'قريباً',
	'trad_definir_reference' => 'اختيار "@titre@" كمرجع للترجمات',
	'trad_reference' => '(مرجع الترجمات)',

	// Z
	'zbug_balise_b_aval' => ': العلامة B متأخرة',
	'zbug_balise_inexistante' => 'خطأ في الاعلان عن العلامة @balise@ لـ@from@',
	'zbug_balise_sans_argument' => 'عامل غير موجود في علامة @balise@',
	'zbug_boucle' => 'حلقة',
	'zbug_boucle_recursive_undef' => 'حلقة دورية غير معرّفة: @nom@',
	'zbug_calcul' => 'حساب',
	'zbug_champ_hors_boucle' => 'الحقل @champ@ خارج الحلقة',
	'zbug_champ_hors_motif' => 'الحقل @champ@ خارج سياق @motif@',
	'zbug_code' => 'الرموز البرمجية',
	'zbug_critere_inconnu' => 'معيار غير معروف @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} على جدول دون مفتاح اساسي افرادي',
	'zbug_distant_interdit' => 'عملية خارجية ممنوعة',
	'zbug_doublon_table_sans_cle_primaire' => 'قيمة مكررة في جدول لا يملك مفتاح أساسي',
	'zbug_doublon_table_sans_index' => 'تكرار في جدول غير مفهرس',
	'zbug_erreur_boucle_double' => 'تعريف متكرر للحلقة @id@',
	'zbug_erreur_boucle_fermant' => 'علامة إغلاق غائبة في حلقة @id@',
	'zbug_erreur_boucle_syntaxe' => 'تركيب حلقة @id@ غير صحيح',
	'zbug_erreur_compilation' => 'خطأ تصنيف',
	'zbug_erreur_execution_page' => 'خطأ في التنفيذ',
	'zbug_erreur_filtre' => 'المرشح @filtre@ غير معرّف ',
	'zbug_erreur_meme_parent' => 'لا ينطبق معيار {meme_parent} إلا على حلقتي (FORUMS) أو (RUBRIQUES)',
	'zbug_erreur_squelette' => 'خطأ في الصفحة النموذجية',
	'zbug_hors_compilation' => 'خارج التصنيف',
	'zbug_info_erreur_squelette' => 'خطأ في الموفع',
	'zbug_inversion_ordre_inexistant' => 'عكس ترتيب غير موجود أصلاً',
	'zbug_pagination_sans_critere' => 'علامة PAGINATION# بدون معيار {pagination} أو مستخدمة في حلقة دورية',
	'zbug_parametres_inclus_incorrects' => 'عامل إدراج غير صحيحة: @param@',
	'zbug_profile' => 'فترة المعالجة: @time@',
	'zbug_resultat' => 'النتيجة',
	'zbug_serveur_indefini' => 'خادم SQL غير محدد',
	'zbug_statistiques' => 'احصاءات استفسارات SQL مرتبة حسب المدة',
	'zbug_table_inconnue' => 'جدول SQL هو «@table@» غير معروف',
	'zxml_connus_attributs' => 'خاصيات معروفة',
	'zxml_de' => 'من',
	'zxml_inconnu_attribut' => 'خاصية غير معروفة',
	'zxml_inconnu_balise' => 'علامة غير معروفة',
	'zxml_inconnu_entite' => 'كائن غير معروف',
	'zxml_inconnu_id' => 'هوية ID غير معروفة',
	'zxml_mais_de' => 'لكن من',
	'zxml_non_conforme' => 'غير مطابق للشكل',
	'zxml_non_fils' => 'ليس من سلالة',
	'zxml_nonvide_balise' => 'علامة غير فارغة',
	'zxml_obligatoire_attribut' => 'خاصية إجبارية لكنها غير موجودة في',
	'zxml_succession_fils_incorrecte' => 'تتابع سلالات غير سليم',
	'zxml_survoler' => 'الحوم لعرض الصحيح',
	'zxml_valeur_attribut' => 'قيمة الخاصية',
	'zxml_vide_balise' => 'علامة فارغة',
	'zxml_vu' => 'ظهر مسبقاً'
);

?>
